@@ -16,15 +16,18 @@ PASSWD = "myshinylittlepassword"
 PASSWD2 = "myshinylittlepassword2"
 PASSWD3 = "myshinylittlepassword3"
 
-def have_luks2():
+
+def check_cryptsetup_version(version):
     try:
-        succ = BlockDev.utils_check_util_version("cryptsetup", "2.0.3", "--version", r"cryptsetup ([0-9+\.]+)")
+        succ = BlockDev.utils_check_util_version("cryptsetup", version, "--version", r"cryptsetup ([0-9+\.]+)")
     except GLib.GError:
         return False
     else:
         return succ
 
-HAVE_LUKS2 = have_luks2()
+
+HAVE_LUKS2 = check_cryptsetup_version("2.0.3")
+HAVE_BITLK = check_cryptsetup_version("2.3.0")
 
 
 class CryptoTestCase(unittest.TestCase):
@@ -225,6 +228,42 @@ class CryptoTestFormat(CryptoTestCase):
             self.fail("Failed to get pbkdf information from:\n%s %s" % (out, err))
         self.assertEqual(int(m.group(1)), 5)
 
+    def _get_luks1_key_size(self, device):
+        _ret, out, err = run_command("cryptsetup luksDump %s" % device)
+        m = re.search(r"MK bits:\s*(\S+)\s*", out)
+        if not m or len(m.groups()) != 1:
+            self.fail("Failed to get key size information from:\n%s %s" % (out, err))
+        key_size = m.group(1)
+        if not key_size.isnumeric():
+            self.fail("Failed to get key size information from: %s" % key_size)
+        return int(key_size)
+
+    @tag_test(TestTags.SLOW, TestTags.CORE)
+    def test_luks_format_key_size(self):
+        """Verify that formating device as LUKS works"""
+
+        # aes-xts: key size should default to 512
+        succ = BlockDev.crypto_luks_format(self.loop_dev, "aes-xts-plain64", 0, PASSWD, None, 0)
+        self.assertTrue(succ)
+
+        key_size = self._get_luks1_key_size(self.loop_dev)
+        self.assertEqual(key_size, 512)
+
+        # aes-cbc: key size should default to 256
+        succ = BlockDev.crypto_luks_format(self.loop_dev, "aes-cbc-essiv:sha256", 0, PASSWD, None, 0)
+        self.assertTrue(succ)
+
+        key_size = self._get_luks1_key_size(self.loop_dev)
+        self.assertEqual(key_size, 256)
+
+        # try specifying key size for aes-xts
+        succ = BlockDev.crypto_luks_format(self.loop_dev, "aes-xts-plain64", 256, PASSWD, None, 0)
+        self.assertTrue(succ)
+
+        key_size = self._get_luks1_key_size(self.loop_dev)
+        self.assertEqual(key_size, 256)
+
+
 class CryptoTestResize(CryptoTestCase):
 
     def _get_key_location(self, device):
@@ -917,6 +956,79 @@ class CryptoTestInfo(CryptoTestCase):
         succ = BlockDev.crypto_luks_close("libblockdevTestLUKS")
         self.assertTrue(succ)
 
+
+class CryptoTestLuksSectorSize(CryptoTestCase):
+    def setUp(self):
+        if not check_cryptsetup_version("2.4.0"):
+            self.skipTest("cryptsetup encryption sector size not available, skipping.")
+
+        # we need a loop devices for this test case
+        self.addCleanup(self._clean_up)
+        self.dev_file = create_sparse_tempfile("crypto_test", 1024**3)
+        self.dev_file2 = create_sparse_tempfile("crypto_test", 1024**3)
+
+        # create a 4k sector loop device
+        ret, out, err = run_command("losetup -f %s --show --sector-size 4096" % self.dev_file)
+        self.assertEqual(ret, 0, "Failed to setup loop device for testing: %s" % err)
+        self.loop_dev = out.strip()
+
+        succ, loop = BlockDev.loop_setup(self.dev_file2)
+        if not succ:
+            raise RuntimeError("Failed to setup loop device for testing")
+        self.loop_dev2 = "/dev/%s" % loop
+
+    def _clean_up(self):
+        try:
+            BlockDev.crypto_luks_close("libblockdevTestLUKS")
+        except:
+            pass
+
+        BlockDev.loop_teardown(self.loop_dev)
+        os.unlink(self.dev_file)
+
+        BlockDev.loop_teardown(self.loop_dev2)
+        os.unlink(self.dev_file2)
+
+    @tag_test(TestTags.SLOW)
+    @unittest.skipUnless(HAVE_LUKS2, "LUKS 2 not supported")
+    def test_luks2_sector_size_autodetect(self):
+        """Verify that we can autodetect 4k drives and set 4k sector size for them"""
+
+        # format the 4k loop device, encryption sector size should default to 4096
+        succ = BlockDev.crypto_luks_format(self.loop_dev, "aes-cbc-essiv:sha256", 256, PASSWD, None, 0,
+                                           BlockDev.CryptoLUKSVersion.LUKS2)
+        self.assertTrue(succ)
+
+        succ = BlockDev.crypto_luks_open(self.loop_dev, "libblockdevTestLUKS", PASSWD, None, False)
+        self.assertTrue(succ)
+
+        info = BlockDev.crypto_luks_info("libblockdevTestLUKS")
+        self.assertIsNotNone(info)
+
+        self.assertEqual(info.version, BlockDev.CryptoLUKSVersion.LUKS2)
+        self.assertEqual(info.sector_size, 4096)
+
+        succ = BlockDev.crypto_luks_close("libblockdevTestLUKS")
+        self.assertTrue(succ)
+
+        # with the 512 loop device, we should still get 512
+        succ = BlockDev.crypto_luks_format(self.loop_dev2, "aes-cbc-essiv:sha256", 256, PASSWD, None, 0,
+                                           BlockDev.CryptoLUKSVersion.LUKS2)
+        self.assertTrue(succ)
+
+        succ = BlockDev.crypto_luks_open(self.loop_dev2, "libblockdevTestLUKS", PASSWD, None, False)
+        self.assertTrue(succ)
+
+        info = BlockDev.crypto_luks_info("libblockdevTestLUKS")
+        self.assertIsNotNone(info)
+
+        self.assertEqual(info.version, BlockDev.CryptoLUKSVersion.LUKS2)
+        self.assertEqual(info.sector_size, 512)
+
+        succ = BlockDev.crypto_luks_close("libblockdevTestLUKS")
+        self.assertTrue(succ)
+
+
 class CryptoTestIntegrity(CryptoTestCase):
     @tag_test(TestTags.SLOW)
     @unittest.skipUnless(HAVE_LUKS2, "LUKS 2 not supported")
@@ -1042,3 +1154,65 @@ class CryptoTestTrueCrypt(CryptoTestCase):
         succ = BlockDev.crypto_tc_close("libblockdevTestTC")
         self.assertTrue(succ)
         self.assertFalse(os.path.exists("/dev/mapper/libblockdevTestTC"))
+
+
+class CryptoTestBitlk(CryptoTestCase):
+
+    # we can't create BitLocker formats using libblockdev
+    # so we are using these images from cryptsetup test suite
+    # https://gitlab.com/cryptsetup/cryptsetup/blob/master/tests/bitlk-images.tar.xz
+    bitlk_img = "bitlk-aes-xts-128.img"
+    passphrase = "anaconda"
+    tempdir = None
+
+    @classmethod
+    def setUpClass(cls):
+        super(CryptoTestBitlk, cls).setUpClass()
+        cls.tempdir = tempfile.mkdtemp(prefix="bd_test_bitlk")
+        images = os.path.join(os.path.dirname(__file__), "bitlk-images.tar.gz")
+        with tarfile.open(images, "r") as tar:
+            tar.extractall(cls.tempdir)
+
+    @classmethod
+    def tearDownClass(cls):
+        super(CryptoTestBitlk, cls).tearDownClass()
+        shutil.rmtree(cls.tempdir)
+
+    def setUp(self):
+        self.addCleanup(self._clean_up)
+
+        succ, loop = BlockDev.loop_setup(os.path.join(self.tempdir, self.bitlk_img))
+        if  not succ:
+            raise RuntimeError("Failed to setup loop device for testing")
+        self.bitlk_dev = "/dev/%s" % loop
+
+    def _clean_up(self):
+        try:
+            BlockDev.crypto_bitlk_close("libblockdevTestBitlk")
+        except:
+            pass
+
+        succ = BlockDev.loop_teardown(self.bitlk_dev)
+        if not succ:
+            raise RuntimeError("Failed to tear down loop device used for testing")
+
+    @unittest.skipUnless(HAVE_BITLK, "BITLK not supported")
+    def test_bitlk_open_close(self):
+        """Verify that opening/closing a BitLocker device works"""
+
+        with self.assertRaises(GLib.GError):
+            BlockDev.crypto_luks_open("/non/existing/device", "libblockdevTestBitlk", self.passphrase)
+
+        with self.assertRaises(GLib.GError):
+            BlockDev.crypto_luks_open(self.bitlk_dev, "libblockdevTestBitlk", None)
+
+        with self.assertRaises(GLib.GError):
+            BlockDev.crypto_luks_open(self.bitlk_dev, "libblockdevTestBitlk", "wrong-passhprase")
+
+        succ = BlockDev.crypto_bitlk_open(self.bitlk_dev, "libblockdevTestBitlk", self.passphrase)
+        self.assertTrue(succ)
+        self.assertTrue(os.path.exists("/dev/mapper/libblockdevTestBitlk"))
+
+        succ = BlockDev.crypto_bitlk_close("libblockdevTestBitlk")
+        self.assertTrue(succ)
+        self.assertFalse(os.path.exists("/dev/mapper/libblockdevTestBitlk"))
