@@ -7,12 +7,29 @@ import six
 import re
 import shutil
 import subprocess
+import time
+from contextlib import contextmanager
 from distutils.version import LooseVersion
 
 from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, TestTags, tag_test, run_command
 from gi.repository import BlockDev, GLib
 
 
+@contextmanager
+def wait_for_sync(vg_name, lv_name):
+    try:
+        yield
+    finally:
+        time.sleep(2)
+        while True:
+            info = BlockDev.lvm_lvinfo(vg_name, lv_name)
+            if not info:
+                break
+            if info.copy_percent == 100:
+                break
+            time.sleep(1)
+
+
 class LVMTestCase(unittest.TestCase):
 
     @classmethod
@@ -61,9 +78,15 @@ class LvmNoDevTestCase(LVMTestCase):
     def test_get_supported_pe_sizes(self):
         """Verify that supported PE sizes are really supported"""
 
-        for size in BlockDev.lvm_get_supported_pe_sizes():
+        supported = BlockDev.lvm_get_supported_pe_sizes()
+
+        for size in supported:
             self.assertTrue(BlockDev.lvm_is_supported_pe_size(size))
 
+        self.assertIn(4 * 1024, supported)
+        self.assertIn(4 * 1024 **2, supported)
+        self.assertIn(16 * 1024**3, supported)
+
     @tag_test(TestTags.NOSTORAGE)
     def test_get_max_lv_size(self):
         """Verify that max LV size is correctly determined"""
@@ -238,14 +261,17 @@ class LvmNoDevTestCase(LVMTestCase):
             BlockDev.lvm_cache_get_mode_from_str("bla")
 
 class LvmPVonlyTestCase(LVMTestCase):
+
+    _sparse_size = 1024**3
+
     # :TODO:
     #     * test pvmove (must create two PVs, a VG, a VG and some data in it
     #       first)
     #     * some complex test for pvs, vgs, lvs, pvinfo, vginfo and lvinfo
     def setUp(self):
         self.addCleanup(self._clean_up)
-        self.dev_file = create_sparse_tempfile("lvm_test", 1024**3)
-        self.dev_file2 = create_sparse_tempfile("lvm_test", 1024**3)
+        self.dev_file = create_sparse_tempfile("lvm_test", self._sparse_size)
+        self.dev_file2 = create_sparse_tempfile("lvm_test", self._sparse_size)
         try:
             self.loop_dev = create_lio_device(self.dev_file)
         except RuntimeError as e:
@@ -667,6 +693,8 @@ class LvmTestLVcreateWithExtra(LvmPVVGLVTestCase):
         self.assertTrue(succ)
 
 class LvmTestLVcreateType(LvmPVVGLVTestCase):
+    _sparse_size = 200 * 1024**2
+
     def test_lvcreate_type(self):
         """Verify it's possible to create LVs with various types"""
 
@@ -680,7 +708,7 @@ class LvmTestLVcreateType(LvmPVVGLVTestCase):
         self.assertTrue(succ)
 
         # try to create a striped LV
-        succ = BlockDev.lvm_lvcreate("testVG", "testLV", 512 * 1024**2, "striped", [self.loop_dev, self.loop_dev2], None)
+        succ = BlockDev.lvm_lvcreate("testVG", "testLV", 100 * 1024**2, "striped", [self.loop_dev, self.loop_dev2], None)
         self.assertTrue(succ)
 
         # verify that the LV has the requested segtype
@@ -690,9 +718,10 @@ class LvmTestLVcreateType(LvmPVVGLVTestCase):
         succ = BlockDev.lvm_lvremove("testVG", "testLV", True, None)
         self.assertTrue(succ)
 
-        # try to create a mirrored LV
-        succ = BlockDev.lvm_lvcreate("testVG", "testLV", 512 * 1024**2, "mirror", [self.loop_dev, self.loop_dev2], None)
-        self.assertTrue(succ)
+        with wait_for_sync("testVG", "testLV"):
+            # try to create a mirrored LV
+            succ = BlockDev.lvm_lvcreate("testVG", "testLV", 100 * 1024**2, "mirror", [self.loop_dev, self.loop_dev2], None)
+            self.assertTrue(succ)
 
         # verify that the LV has the requested segtype
         info = BlockDev.lvm_lvinfo("testVG", "testLV")
@@ -701,9 +730,10 @@ class LvmTestLVcreateType(LvmPVVGLVTestCase):
         succ = BlockDev.lvm_lvremove("testVG", "testLV", True, None)
         self.assertTrue(succ)
 
-        # try to create a raid1 LV
-        succ = BlockDev.lvm_lvcreate("testVG", "testLV", 512 * 1024**2, "raid1", [self.loop_dev, self.loop_dev2], None)
-        self.assertTrue(succ)
+        with wait_for_sync("testVG", "testLV"):
+            # try to create a raid1 LV
+            succ = BlockDev.lvm_lvcreate("testVG", "testLV", 100 * 1024**2, "raid1", [self.loop_dev, self.loop_dev2], None)
+            self.assertTrue(succ)
 
         # verify that the LV has the requested segtype
         info = BlockDev.lvm_lvinfo("testVG", "testLV")
